@@ -11,11 +11,12 @@ from django.db.models.fields import Field, CharField
 from django.utils.encoding import force_unicode
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
+from django.core import urlresolvers
 
 # FILEBROWSER IMPORTS
 from filebrowser.settings import *
 from filebrowser.base import FileObject
-from filebrowser.functions import url_to_path
+from filebrowser.sites import site
 
 
 class FileBrowseWidget(Input):
@@ -26,6 +27,7 @@ class FileBrowseWidget(Input):
     
     def __init__(self, attrs=None):
         super(FileBrowseWidget, self).__init__(attrs)
+        self.site = attrs.get('site', None)
         self.directory = attrs.get('directory', '')
         self.extensions = attrs.get('extensions', '')
         self.format = attrs.get('format', '')
@@ -36,20 +38,22 @@ class FileBrowseWidget(Input):
         super(FileBrowseWidget, self).__init__(attrs)
     
     def render(self, name, value, attrs=None):
+        url = urlresolvers.reverse(self.site.name + ":fb_browse")
         if value is None:
             value = ""
+        if value != "" and not isinstance(value, FileObject):
+            value = FileObject(value, site=self.site)
         final_attrs = self.build_attrs(attrs, type=self.input_type, name=name)
         final_attrs['search_icon'] = URL_FILEBROWSER_MEDIA + 'img/filebrowser_icon_show.gif'
+        final_attrs['url'] = url
         final_attrs['directory'] = self.directory
         final_attrs['extensions'] = self.extensions
         final_attrs['format'] = self.format
         final_attrs['ADMIN_THUMBNAIL'] = ADMIN_THUMBNAIL
+        site = self.site
         if value != "":
             try:
-                if value.is_version and VERSIONS_BASEDIR:
-                    final_attrs['directory'] = os.path.split(value.original.path_relative_directory)[0]
-                else:
-                    final_attrs['directory'] = os.path.split(value.path_relative_directory)[0]
+                final_attrs['directory'] = os.path.split(value.original.path_relative_directory)[0]
             except:
                 pass
         return render_to_string("filebrowser/custom_field.html", locals())
@@ -61,8 +65,9 @@ class FileBrowseFormField(forms.CharField):
         'extension': _(u'Extension %(ext)s is not allowed. Only %(allowed)s is allowed.'),
     }
     
-    def __init__(self, max_length=None, min_length=None, directory=None, extensions=None, format=None, *args, **kwargs):
+    def __init__(self, max_length=None, min_length=None, site=None, directory=None, extensions=None, format=None, *args, **kwargs):
         self.max_length, self.min_length = max_length, min_length
+        self.site = site
         self.directory = directory
         self.extensions = extensions
         if format:
@@ -85,6 +90,7 @@ class FileBrowseField(CharField):
     __metaclass__ = models.SubfieldBase
     
     def __init__(self, *args, **kwargs):
+        self.site = kwargs.pop('site', site)
         self.directory = kwargs.pop('directory', '')
         self.extensions = kwargs.pop('extensions', '')
         self.format = kwargs.pop('format', '')
@@ -93,29 +99,40 @@ class FileBrowseField(CharField):
     def to_python(self, value):
         if not value or isinstance(value, FileObject):
             return value
-        return FileObject(url_to_path(value))
+        return FileObject(value, site=self.site)
     
     def get_db_prep_value(self, value, connection, prepared=False):
         if not value:
             return value
-        return value.url_save
+        return value.path
+
+    def value_to_string(self, obj):
+        value = self._get_val_from_obj(obj)
+        if not value:
+            return value
+        return value.path
     
     def formfield(self, **kwargs):
         attrs = {}
+        attrs["site"] = self.site
         attrs["directory"] = self.directory
         attrs["extensions"] = self.extensions
         attrs["format"] = self.format
         defaults = {
             'form_class': FileBrowseFormField,
             'widget': FileBrowseWidget(attrs=attrs),
+            'site': self.site,
             'directory': self.directory,
             'extensions': self.extensions,
             'format': self.format
         }
         return super(FileBrowseField, self).formfield(**defaults)
 
+
 try:
     from south.modelsinspector import add_introspection_rules
     add_introspection_rules([], ["^filebrowser\.fields\.FileBrowseField"])
 except:
     pass
+
+
